@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -1034,7 +1034,7 @@ class PluginManager(QObject):
             pluginName in self.__onDemandActiveModules
     
     ###########################################################################
-    ## Specialized plugin module handling methods below
+    ## Specialized plug-in module handling methods below
     ###########################################################################
     
     ###########################################################################
@@ -1254,7 +1254,13 @@ class PluginManager(QObject):
                 self.__updateAvailable = True
             return
         
-        if pluginDetails["version"] < version:
+        if version.count(".") >= 3:
+            # cope for extended version numbers by ignoring
+            # the extension
+            checkVersion = ".".join(version.split(".", 3)[:3])
+        else:
+            checkVersion = version
+        if pluginDetails["version"] < checkVersion:
             self.__updateAvailable = True
             return
         
@@ -1291,6 +1297,30 @@ class PluginManager(QObject):
         ignored = self.__sslErrorHandler.sslErrorsReply(reply, errors)[0]
         if ignored == E5SslErrorHandler.NotIgnored:
             self.__downloadCancelled = True
+    
+    ########################################################################
+    ## Methods to clear private data of plug-ins below
+    ########################################################################
+    
+    def clearPluginsPrivateData(self, type_):
+        """
+        Public method to clear the private data of plug-ins of a specified
+        type.
+        
+        Plugins supporting this functionality must support the module function
+        clearPrivateData() and have the module level attribute pluginType.
+        
+        @param type_ type of the plugin to be activated (string)
+        """
+        for name, module in \
+            list(self.__onDemandActiveModules.items()) + \
+            list(self.__onDemandInactiveModules.items()) + \
+            list(self.__activeModules.items()) + \
+                list(self.__inactiveModules.items()):
+            if getattr(module, "pluginType", "") == type_:
+                if hasattr(module, "clearPrivateData"):
+                    module.clearPrivateData()
+        # TODO: document this in the plug-ins paper
 
 #
 # eflag: noqa = M801
