@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -244,16 +244,6 @@ class VersionControl(QObject):
         """
         raise RuntimeError('Not implemented')
         
-    def vcsLog(self, name):
-        """
-        Public method used to view the log of a file/directory in the vcs.
-        
-        @param name file/directory name to show the log for (string)
-        @exception RuntimeError to indicate that this method must be
-            implemented by a subclass
-        """
-        raise RuntimeError('Not implemented')
-        
     def vcsLogBrowser(self, name, isFile=False):
         """
         Public method used to view the log of a file/directory in the vcs
@@ -666,7 +656,7 @@ class VersionControl(QObject):
         """
         if project.pudata["VCSSTATUSMONITORINTERVAL"]:
             vcsStatusMonitorInterval = project.pudata[
-                "VCSSTATUSMONITORINTERVAL"][0]
+                "VCSSTATUSMONITORINTERVAL"]
         else:
             vcsStatusMonitorInterval = Preferences.getVCS(
                 "StatusMonitorInterval")
